Name:           livestreamer
Version:        1.12.2
#Release:        7%{?dist}
Release:        9%{?dist}
License:        BSD and MIT
Summary:        Extracts streams and pipes them into a video player of choice
Url:            http://livestreamer.tanuki.se/
Group:          Applications/Internet
Source:         https://pypi.python.org/packages/source/l/%{name}/%{name}-%{version}.tar.gz

%define backport %{nil}
%if 0%{?rhel}%{?fedora}
  %if 0%{?rhel}
    %if 0%{?rhel} <= 7
      %define backport 1
    %endif
  %endif
%endif

%if 0%{?backport}
BuildRequires:  python34
BuildRequires:  python34-devel
BuildRequires:  python34-setuptools
BuildRequires:  python34-requests
BuildRequires:  python-requests
#BuildRequires:  rh-python34-python-sphinx
BuildRequires:  python-sphinx
%else
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-requests
BuildRequires:  python3-sphinx
%endif
BuildRequires:  python-singledispatch
BuildRequires:  python-futures
BuildRequires:  dos2unix
%if 0%{?backport}
Requires:       python34
Requires:       python34-requests
%else
Requires:       python3-requests
%endif
Requires:       fontawesome-fonts

BuildArch:      noarch

%if 0%{?backport}
#define python_backport_setup export PATH="${/opt/rh/rh-python34/root/usr/bin/:PATH}" ; export LD_LIBRARY_PATH="/opt/rh/rh-python34/root/usr/lib64:/opt/rh/rh-python34/root/usr/lib:${LD_LIBRARY_PATH}"
#define python_backport /opt/rh/rh-python34/root/usr/bin/python3
%endif

%description
Livestreamer is a CLI program that extracts streams from various services and
pipes them into a video player of choice.
Livestreamer is built upon a plugin system which allows support for new
services to be easily added.

%prep
%setup -q -n %{name}-%{version}

# edit .py file and use python3
find . -name '*.py' | xargs sed -i '1s|^#!python|#!%{__python3}|'

# delete version-control-internal-file
find . -name .gitignore -exec rm -f {} \; >/dev/null
# remove bundles fonts
rm -r docs/_themes/sphinx_rtd_theme_violet/static/fonts
# Remove bundled egg-info
rm -rf src/livestreamer.egg-info

%build
%{__python3} setup.py build

# Generate man page and html documentation (needs python-sphinx)
%if 0%{?backport}
#{?python_backport_setup}
#{python_backport} setup.py build_sphinx -b man
#{python_backport} setup.py build_sphinx -b html
python setup.py build_sphinx -b man
python setup.py build_sphinx -b html
%else
%{__python3} setup.py build_sphinx -b man
%{__python3} setup.py build_sphinx -b html
%endif

%install
%{__python3} setup.py install --root=%{buildroot} --skip-build
for file in %{buildroot}%{python3_sitelib}/%{name}/packages/flashmedia/{tag,packet,__init__,flv,f4v,util,error}.py; do
    chmod a+x $file
done

# install man page
install -p -d -m755 %{buildroot}%{_mandir}/man1
# rename manual page due rpmlint warning W: no-manual-page-for-binary python3-livestreamer
install -p -m644 build/sphinx/man/%{name}.1 %buildroot%{_mandir}/man1/%{name}.1

# install html docs
install -p -d -m755 %{buildroot}%{_docdir}/%{name}
mv build/sphinx/html %{buildroot}%{_docdir}/%{name} 

# convert to unix format due rpmlint warning W: wrong-file-end-of-line-encoding
dos2unix %{buildroot}/%{_docdir}/%{name}/html/_static/jquery.js

# convert to utf8 due rpmlint warning W: file-not-utf8 /usr/share/doc/python-livestreamer/html/objects.inv
iconv -f iso-8859-1 -t utf-8 %{buildroot}/%{_docdir}/%{name}/html/objects.inv > objects.inv.utf8; \
mv objects.inv.utf8 %{buildroot}/%{_docdir}/%{name}/html/objects.inv

# E: non-executable-script /usr/lib/python3.5/site-packages/livestreamer/plugins/tvplayer.py
chmod a+x %{buildroot}%{python3_sitelib}/%{name}/plugins/{tvplayer,tv3cat}.py

# convert to unix format due rpmlint warning W: wrong-file-end-of-line-encoding
dos2unix %{buildroot}/%{_docdir}/%{name}/html/objects.inv

# Sphinx info file for hashing, no longer needed 
rm %{buildroot}/%{_docdir}/%{name}/html/.buildinfo

%check
%{__python3} setup.py test

%files
%doc *.rst
%license LICENSE*
%{_bindir}/%{name}
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}_cli
%{python3_sitelib}/%{name}-%{version}-py*.egg-info
%{_datadir}/doc/%{name}/html
%{_mandir}/man1/%{name}.1.*

%changelog
* Sun Oct 01 2017 Tomasz Tomasik <scx.mail@gmail.com> - 1.12.2-9
- Add requirement: python-requests
- Rebuilt for EL7

* Fri Apr 14 2017 Tomasz Tomasik <scx.mail@gmail.com> - 1.12.2-8
- Backport for EL7
- Rebuilt for EL7

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 1.12.2-6
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.12.2-5
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Nov 14 2015 Martin Gansser <martinkg@fedoraproject.org> - 1.12.2-3
- Changed file permisson due rpmlint warning non-executable-scripts
- Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.12.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun May 03 2015 Martin Gansser <martinkg@fedoraproject.org> - 1.12.2-1
- Update to 1.12.2

* Mon Mar 23 2015 Martin Gansser <martinkg@fedoraproject.org> - 1.12.1-1
- Update to 1.12.1

* Mon Mar 02 2015 Martin Gansser <martinkg@fedoraproject.org> - 1.12.0-1
- Update to 1.12.0
- dropped plugins-hitbox-Refactor-to-use-the-StreamMapper.patch
- spec file cleanup

* Sun Feb 15 2015 Martin Gansser <martinkg@fedoraproject.org> - 1.11.1-7
- renamed package from python-livestreamer to livestreamer
- cleanup spec file
- fixed typos
- removed whitespace

* Sun Feb 15 2015 Martin Gansser <martinkg@fedoraproject.org> - 1.11.1-6
- Install html docs directly instead of adding them to %%doc
- Convert files with dos2unix in unix format
- Convert files in utf8 format
- Deleted Sphinx hash file
- Reverted package name
- Dropped url address for patch0
- Make install preserve timestamps
- Renamed man page
- Used wildcard for manpage
- Added BR dos2unix
- Added R python3-requests

* Sun Feb 15 2015 Martin Gansser <martinkg@fedoraproject.org> - 1.11.1-5
- dropped Py2 package, because Py2 support ends in a few months
- cleanup spec file
- renamed package to python3-livestreamer

* Fri Feb 13 2015 Martin Gansser <martinkg@fedoraproject.org> - 1.11.1-4
- Dropped CFLAGS for noarch package
- Dropped BR in subpackage python3-livestreamer due redundancy
- Removed bundled livestreamer.egg-info
- Added R python3-requests
- Generate man page and html documentation
- Added BR python-sphinx
- Added plugins-hitbox-Refactor-to-use-the-StreamMapper.patch

* Thu Feb 12 2015 Martin Gansser <martinkg@fedoraproject.org> - 1.11.1-3
- Added BR python-futures
- Added BR python-requests
- Added BR python-singledispatch
- Added BR python3-requests to subpackage python3-livestreamer
- Added R fontawesome-fonts to subpackage python3-livestreamer

* Tue Feb 10 2015 Martin Gansser <martinkg@fedoraproject.org> - 1.11.1-2
- Removed bundled fonts
- Added fontawesome-fonts requires.

* Sat Feb 07 2015 Martin Gansser <martinkg@fedoraproject.org> - 1.11.1-1
- Initial package for fc21
